Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1016)

Unified Diff: chrome/browser/ui/toolbar/wrench_menu_model.h

Issue 10837317: Setting the touch wrench menu as default menu for ChromeOS (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed build problems Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/toolbar/wrench_menu_model.h
diff --git a/chrome/browser/ui/toolbar/wrench_menu_model.h b/chrome/browser/ui/toolbar/wrench_menu_model.h
index d2f65f7a01f970ab60baf681835a88be07d47f25..cf650511e8de043bda355e98e85652f6b53fb091 100644
--- a/chrome/browser/ui/toolbar/wrench_menu_model.h
+++ b/chrome/browser/ui/toolbar/wrench_menu_model.h
@@ -133,13 +133,14 @@ class WrenchMenuModel : public ui::SimpleMenuModel,
// Appends everything needed for the clipboard menu: a menu break, the
// clipboard menu content and the finalizing menu break. If the last break
- // is not needed it can be suppressed by setting |append_final_separator|
+ // is not needed it can be suppressed by setting |new_menu|
// to false.
- void CreateCutCopyPasteMenu(bool append_final_separator);
+ void CreateCutCopyPasteMenu(bool new_menu);
// Appends everything needed for the zoom menu: a menu break, then the zoom
- // menu content and then another menu break.
- void CreateZoomMenu();
+ // menu content and then another menu break. If the new menu type is used,
+ // |new_menu| should be set to true.
+ void CreateZoomMenu(bool new_menu);
string16 GetSyncMenuLabel() const;

Powered by Google App Engine
This is Rietveld 408576698